window.Gleam.initSearch([{"doc":"cosepo","title":"cosepo","content":"# cosepo\n\n[![Package Version](https://img.shields.io/hexpm/v/cosepo)](https://hex.pm/packages/cosepo)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/cosepo/)\n\nA module for parsing, mutating, and serializing Content-Security-Policy directives.\n\n## Installation\n\n```sh\ngleam add cosepo\n```\n\n## Usage\n\n```gleam\nimport cosepo\nimport cosepo/directive\n\npub fn main() {\n  cosepo.parse(&quot;default-src https: &#39;unsafe-eval&#39; &#39;unsafe-inline&#39;; object-src &#39;none&#39;&quot;)\n  // -&gt; Ok(ContentSecurityPolicy([\n  //   Directive(&quot;default-src&quot;, [&quot;https:&quot;, &quot;&#39;unsafe-eval&#39;&quot;, &quot;&#39;unsafe-inline&#39;&quot;]),\n  //   Directive(&quot;object-src&quot;, [&quot;&#39;none&#39;&quot;])])\n  // )\n\n  let assert Ok(directive1) = directive.new_directive(&quot;default-src&quot;, [&quot;&#39;none&#39;&quot;])\n  let assert Ok(directive2) = directive.new_directive(&quot;script-src&quot;, [&quot;https://example.com&quot;])\n  cosepo.serialize(ContentSecurityPolicy([directive1, directive2]))\n  // -&gt; &quot;default-src &#39;none&#39;; script-src https://example.com;&quot;\n\n  directive.new_directive(&quot;an-invalid-directive&quot;, [])\n  // -&gt; Error(&quot;an-invalid-directive is not a valid directive name&quot;)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/cosepo&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"cosepo/directive","title":"Directive","content":"pub opaque type Directive\n Use `.new_directive(name: String, value: String)` to construct a `Directive` \n\nSynonyms:\ncosepo/directive.Directive\ncosepo/directive Directive","url":"cosepo/directive.html#Directive"},{"doc":"cosepo/directive","title":"get_name","content":"pub fn get_name(directive: Directive) -&gt; String\n Returns the name of a directive\n \n ## Example\n \n Directive(&quot;default-src&quot;, [&quot;&#39;none&#39;&quot;])\n |&gt; get_name // -&gt; &quot;default-src&quot;\n \nSynonyms:\ncosepo/directive.get_name\ncosepo/directive get_name","url":"cosepo/directive.html#get_name"},{"doc":"cosepo/directive","title":"get_value","content":"pub fn get_value(directive: Directive) -&gt; List(String)\n Returns the value of a directive\n \n ## Example\n \n Directive(&quot;default-src&quot;, [&quot;&#39;none&#39;&quot;])\n |&gt; get_value // -&gt; [&quot;&#39;none&#39;&quot;]\n \nSynonyms:\ncosepo/directive.get_value\ncosepo/directive get_value","url":"cosepo/directive.html#get_value"},{"doc":"cosepo/directive","title":"new_directive","content":"pub fn new_directive(\n  name name: String,\n  value value: List(String),\n) -&gt; Result(Directive, String)\n Creates a new `Directive`, validating the directive name\n and values.\n\n ## Example\n \n new_directive(&quot;default-src&quot;, [&quot;&#39;self&#39;&quot;])\n // -&gt; Ok(Directive(name: &quot;default-src&quot;, value: [&quot;&#39;self&#39;&quot;]))\n\n new_directive(&quot;invalid-directive&quot;, [])\n // -&gt; Error(&quot;invalid-directive is not a valid directive name&quot;)\n \nSynonyms:\ncosepo/directive.new_directive\ncosepo/directive new_directive","url":"cosepo/directive.html#new_directive"},{"doc":"cosepo/directive","title":"cosepo/directive","content":"","url":"cosepo/directive.html"},{"doc":"cosepo","title":"ContentSecurityPolicy","content":"pub type ContentSecurityPolicy {\n  ContentSecurityPolicy(directives: List(Directive))\n}\n\nContentSecurityPolicy(directives: List(Directive))\n\n\nSynonyms:\ncosepo.ContentSecurityPolicy\ncosepo ContentSecurityPolicy","url":"cosepo.html#ContentSecurityPolicy"},{"doc":"cosepo","title":"merge","content":"pub fn merge(\n  content_security_policy: ContentSecurityPolicy,\n  directive: Directive,\n) -&gt; ContentSecurityPolicy\n Merges a Directive with an existing ContentSecurityPolicy\n \n ## Example\n \n let existing_csp = parse(&quot;default-src &#39;self&#39;;&quot;)\n let assert Ok(directive) = new_directive(&quot;default-src&quot;, [&quot;https://example.com/&quot;])\n merge(existing_csp, directive)\n // -&gt; ContentSecurityPolicy([\n //   Directive(&quot;default-src&quot;, [&quot;&#39;self&#39;&quot;, &quot;https://example.com&quot;])\n // ])\n \nSynonyms:\ncosepo.merge\ncosepo merge","url":"cosepo.html#merge"},{"doc":"cosepo","title":"parse","content":"pub fn parse(\n  serialized_csp: String,\n) -&gt; Result(ContentSecurityPolicy, String)\n Parses a serialized content security policy string\n https://www.w3.org/TR/CSP3/#parse-serialized-policy\n \n ## Example\n \n parse(&quot;default-src &#39;self&#39;&quot;)\n // -&gt; Ok(ContentSecurityPolicy(directives: [\n //      Directive(name: &quot;default-src&quot;, value: [&quot;&#39;self&#39;&quot;]),\n //    ]))\n \n parse(&quot;invalid-directive &#39;self&#39;&quot;)\n // -&gt; Error(&quot;invalid-directive is not a valid directive name&quot;)\n \nSynonyms:\ncosepo.parse\ncosepo parse","url":"cosepo.html#parse"},{"doc":"cosepo","title":"serialize","content":"pub fn serialize(\n  content_security_policy: ContentSecurityPolicy,\n) -&gt; String\n Generates a serialized string, suitable for the Content-Security-Policy\n HTTP header.\n \n ## Example\n \n let assert Ok(content_security_policy) = parse(&quot;default-src &#39;self&#39;;&quot;)\n content_security_policy |&gt; serialize\n // -&gt; &quot;default-src &#39;self&#39;;&quot;\n \nSynonyms:\ncosepo.serialize\ncosepo serialize","url":"cosepo.html#serialize"},{"doc":"cosepo","title":"set","content":"pub fn set(\n  content_security_policy: ContentSecurityPolicy,\n  directive: Directive,\n) -&gt; ContentSecurityPolicy\n Modifies a ContentSecurityPolicy, overwriting a previous directive, if present\n \n ## Example\n \n let assert Ok(content_security_policy) = parse(&quot;default-src &#39;self&#39;&quot;)\n let assert Ok(directive) = new_directive(&quot;default-src&quot;, [&quot;&#39;none&#39;&quot;])\n set(content_security_policy, directive) |&gt; serialize\n // -&gt; &quot;default-src &#39;none&#39;;&quot;\n \nSynonyms:\ncosepo.set\ncosepo set","url":"cosepo.html#set"},{"doc":"cosepo","title":"cosepo","content":"","url":"cosepo.html"}]);